@@ -25,8 +25,8 @@
  * 桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:46:34 $
+ * $Revision: 1.3 $
+ * $Date: 2010/06/22 05:37:35 $
  *
  **********************************************************/
 
@@ -121,7 +121,14 @@ if (isset($_POST["login"]) === TRUE) {
 
         if (sess_start($_POST["user"], $_POST["passwd"], $sesskey, $chk_mode) === TRUE) {
             result_log(":OK:󤷤ޤ");
-            dgp_location("user_mod.php");
+            if (read_tab_conf(USERTABCONF) === FALSE) {
+                $sys_err = TRUE;
+                $pg->display(NULL);
+                exit (1);
+            }
+            $script = key($tab_conf);
+            $tab = key($tab_conf[$script][0]);
+            dgp_location($script . "/" . $tab . "/index.php");
             exit (0);
         } 
         if (isset($env["ldap_server_down"])) {
